.. _shower:

****************************************************
Air shower image I/O and analysis (`gammapy.shower`)
****************************************************

.. currentmodule:: gammapy.shower

Introduction
============

`gammapy.shower` contains air shower image I/O and analysis methods.

TODO: document

Getting Started
===============

TODO: document

Reference/API
=============

.. automodapi:: gammapy.shower
    :no-inheritance-diagram:
